@@ -31,6 +31,10 @@ class PbP:
         else:
             self.game_date = pbp_df["game_date"].unique()[0]
 
+        # change column types to fit my database at a later time on insert
+
+        self.df["scoremargin"] = self.df["scoremargin"].astype(str)
+
         # calculating home and away possesions to later aggregate for players
         # and teams
 
@@ -194,18 +198,16 @@ class PbP:
         function to calculate player's offensive and defensive rebound totals
         """
         rebounds = (
-            self.df.groupby(["player1_id", "game_id", "game_date", "player1_team_id"])[
+            self.df.groupby(["player1_id", "game_id", "game_date"])[
                 ["is_o_rebound", "is_d_rebound"]
             ]
             .sum()
             .reset_index()
         )
 
-        rebounds["player1_team_id"] = rebounds["player1_team_id"].astype(int)
         rebounds.rename(
             columns={
                 "player1_id": "player_id",
-                "player1_team_id": "team_id",
                 "is_o_rebound": "oreb",
                 "is_d_rebound": "dreb",
             },
@@ -1776,7 +1778,7 @@ class PbP:
             shift_dfs.extend([pbp_df.iloc[past_index + 1 : i + 1, :].reset_index()])
             past_index = i
 
-        poss_df = pd.concat(self.parse_possessions(shift_dfs))
+        poss_df = pd.concat(self.parse_possessions(shift_dfs), sort=True)
 
         return poss_df
 
@@ -1805,9 +1807,7 @@ class PbP:
         pbg = pbg.merge(
             assists, how="left", on=["player_id", "team_id", "game_date", "game_id"]
         )
-        pbg = pbg.merge(
-            rebounds, how="left", on=["player_id", "team_id", "game_date", "game_id"]
-        )
+        pbg = pbg.merge(rebounds, how="left", on=["player_id", "game_date", "game_id"])
         pbg = pbg.merge(
             turnovers, how="left", on=["player_id", "team_id", "game_date", "game_id"]
         )
